@@ -6,8 +6,9 @@ pub mod binary_search;
 pub mod bitset;
 pub mod cmp;
 pub mod combinatorics;
+pub mod fenwick_tree_static;
 pub mod longest_common_prefix;
-pub mod modular;
+pub mod modular_static;
 pub mod power;
 pub mod segment_tree;
 pub mod segment_tree_static;
@@ -20,4 +21,3 @@ pub mod suffix_array;
 pub mod tensor;
 pub mod union_find;
 pub mod vector_util;
-pub mod abstract_traits_2;
